@@ -8,7 +8,7 @@ def save_png(width: int, height: int, colors: [palette.RGBA], output: str):
     num_colors = len(colors)
     color_width = width / num_colors
     for i, color in enumerate(colors):
-        hex_name = palette.RGBA_to_tuple(color)
+        hex_name = palette.RGBA_to_rgb_tuple(color)
         draw.rectangle([(color_width * i, 0), (color_width * (i + 1), height)], fill=hex_name)
     
     img.save(output)
